package DateTime::Event::Jewish::ZoneLocation;

=head1 NAME

@(#)zone.tab	1.32 - TZ zone descriptions

=head1 AUTHOR

 From Paul Eggert (1996-08-05):

=head1 DESCRIPTION

This file contains a table with the following columns:

=over

=item *

ISO 3166 2-character country code.  See the file `iso3166.tab'.

=item *

Latitude and longitude of the zone's principal location
in ISO 6709 sign-degrees-minutes-seconds format,
either +-DDMM+-DDDMM or +-DDMMSS+-DDDMMSS,
first latitude (+ is north), then longitude (+ is east).

=item *
 
Zone name used in value of TZ environment variable.

=item *

Comments; present if and only if the country has multiple rows.

=back

Columns are separated by a single tab.
The table is sorted first by country, then an order within the country that
(1) makes some geographical sense, and
 (2) puts the most populous zones first, where that does not contradict (1).

=cut

# Lines beginning with `#' are comments.
#
%zonelocation = (
#code	coordinates	TZ			comments
"Europe/Andorra"=>	[ 42.5, 1.51666666666667],
"Asia/Dubai"=>	[ 25.3, 55.3],
"Asia/Kabul"=>	[ 34.5166666666667, 69.2],
"America/Antigua"=>	[ 17.05, -61.8],
"America/Anguilla"=>	[ 18.2, -63.0666666666667],
"Europe/Tirane"=>	[ 41.3333333333333, 19.8333333333333],
"Asia/Yerevan"=>	[ 40.1833333333333, 44.5],
"America/Curacao"=>	[ 12.1833333333333, -69],
"Africa/Luanda"=>	[ -8.8, 13.2333333333333],
"Antarctica/McMurdo"=>	[ -77.8333333333333, 166.6],
"Antarctica/South_Pole"=>	[ -90, 0],
"Antarctica/Rothera"=>	[ -67.5666666666667, -68.1333333333333],
"Antarctica/Palmer"=>	[ -64.8, -64.1],
"Antarctica/Mawson"=>	[ -67.6, 62.8833333333333],
"Antarctica/Davis"=>	[ -68.5833333333333, 77.9666666666667],
"Antarctica/Casey"=>	[ -66.2833333333333, 110.516666666667],
"Antarctica/Vostok"=>	[ -78.4, 106.9],
"Antarctica/DumontDUrville"=>	[ -66.6666666666667, 140.016666666667],
"Antarctica/Syowa"=>	[ -69, 39.5833333333333],
"America/Argentina/Buenos_Aires"=>	[ -34.6, -58.45],
"America/Argentina/Cordoba"=>	[ -31.4, -64.1833333333333],
"America/Argentina/Jujuy"=>	[ -24.1833333333333, -65.3],
"America/Argentina/Tucuman"=>	[ -31.4, -64.1833333333333],
"America/Argentina/Catamarca"=>	[ -28.4666666666667, -65.7833333333333],
"America/Argentina/La_Rioja"=>	[ -29.4333333333333, -66.85],
"America/Argentina/San_Juan"=>	[ -31.5333333333333, -68.5166666666667],
"America/Argentina/Mendoza"=>	[ -32.8833333333333, -68.8166666666667],
"America/Argentina/Rio_Gallegos"=>	[ -51.6333333333333, -69.2166666666667],
"America/Argentina/Ushuaia"=>	[ -54.8, -68.3],
"Pacific/Pago_Pago"=>	[ -14.2666666666667, -170.7],
"Europe/Vienna"=>	[ 48.2166666666667, 16.3333333333333],
"Australia/Lord_Howe"=>	[ -31.55, 159.083333333333],
"Australia/Hobart"=>	[ -42.8833333333333, 147.316666666667],
"Australia/Currie"=>	[ -39.9333333333333, 143.866666666667],
"Australia/Melbourne"=>	[ -37.8166666666667, 144.966666666667],
"Australia/Sydney"=>	[ -33.8666666666667, 151.216666666667],
"Australia/Broken_Hill"=>	[ -31.95, 141.45],
"Australia/Brisbane"=>	[ -27.4666666666667, 153.033333333333],
"Australia/Lindeman"=>	[ -20.2666666666667, 149],
"Australia/Adelaide"=>	[ -34.9166666666667, 138.583333333333],
"Australia/Darwin"=>	[ -12.4666666666667, 130.833333333333],
"Australia/Perth"=>	[ -31.95, 115.85],
"America/Aruba"=>	[ 12.5, -68.9666666666667],
"Europe/Mariehamn"=>	[ 60.1, 19.95],
"Asia/Baku"=>	[ 40.3833333333333, 49.85],
"Europe/Sarajevo"=>	[ 43.8666666666667, 18.4166666666667],
"America/Barbados"=>	[ 13.1, -59.6166666666667],
"Asia/Dhaka"=>	[ 23.7166666666667, 90.4166666666667],
"Europe/Brussels"=>	[ 50.8333333333333, 4.33333333333333],
"Africa/Ouagadougou"=>	[ 12.3666666666667, -1.51666666666667],
"Europe/Sofia"=>	[ 42.6833333333333, 23.3166666666667],
"Asia/Bahrain"=>	[ 26.3833333333333, 50.5833333333333],
"Africa/Bujumbura"=>	[ -3.38333333333333, 29.3666666666667],
"Africa/Porto-Novo"=>	[ 6.48333333333333, 2.61666666666667],
"Atlantic/Bermuda"=>	[ 32.2833333333333, -64.7666666666667],
"Asia/Brunei"=>	[ 4.93333333333333, 114.916666666667],
"America/La_Paz"=>	[ -16.5, -68.15],
"America/Noronha"=>	[ -3.85, -32.4166666666667],
"America/Belem"=>	[ -1.45, -48.4833333333333],
"America/Fortaleza"=>	[ -3.71666666666667, -38.5],
"America/Recife"=>	[ -8.05, -34.9],
"America/Araguaina"=>	[ -7.2, -48.2],
"America/Maceio"=>	[ -9.66666666666667, -35.7166666666667],
"America/Bahia"=>	[ -12.9833333333333, -38.5166666666667],
"America/Sao_Paulo"=>	[ -23.5333333333333, -46.6166666666667],
"America/Campo_Grande"=>	[ -20.45, -54.6166666666667],
"America/Cuiaba"=>	[ -15.5833333333333, -56.0833333333333],
"America/Porto_Velho"=>	[ -8.76666666666667, -63.9],
"America/Boa_Vista"=>	[ 2.81666666666667, -60.6666666666667],
"America/Manaus"=>	[ -3.13333333333333, -60.0166666666667],
"America/Eirunepe"=>	[ -6.66666666666667, -69.8666666666667],
"America/Rio_Branco"=>	[ -9.96666666666667, -67.8],
"America/Nassau"=>	[ 25.0833333333333, -77.35],
"Asia/Thimphu"=>	[ 27.4666666666667, 89.65],
"Africa/Gaborone"=>	[ -25.75, 25.9166666666667],
"Europe/Minsk"=>	[ 53.9, 27.5666666666667],
"America/Belize"=>	[ 17.5, -88.2],
"America/St_Johns"=>	[ 47.5666666666667, -52.7166666666667],
"America/Halifax"=>	[ 44.65, -63.6],
"America/Glace_Bay"=>	[ 46.2, -59.95],
"America/Goose_Bay"=>	[ 53.3333333333333, -60.4166666666667],
"America/Montreal"=>	[ 45.5166666666667, -73.5666666666667],
"America/Toronto"=>	[ 43.65, -79.3833333333333],
"America/Nipigon"=>	[ 49.0166666666667, -88.2666666666667],
"America/Thunder_Bay"=>	[ 48.3833333333333, -89.25],
"America/Pangnirtung"=>	[ 66.1333333333333, -65.7333333333333],
"America/Iqaluit"=>	[ 63.7333333333333, -68.4666666666667],
"America/Coral_Harbour"=>	[ 64.1333333333333, -83.1666666666667],
"America/Rankin_Inlet"=>	[ 62.75, -92.1666666666667],
"America/Winnipeg"=>	[ 49.8833333333333, -97.15],
"America/Rainy_River"=>	[ 48.7166666666667, -94.4833333333333],
"America/Cambridge_Bay"=>	[ 69.05, -105.083333333333],
"America/Regina"=>	[ 50.4, -104.65],
"America/Swift_Current"=>	[ 50.2833333333333, -107.833333333333],
"America/Edmonton"=>	[ 53.55, -113.466666666667],
"America/Yellowknife"=>	[ 62.45, -114.35],
"America/Inuvik"=>	[ 68.4166666666667, -113.5],
"America/Dawson_Creek"=>	[ 59.7666666666667, -120.233333333333],
"America/Vancouver"=>	[ 49.2666666666667, -123.116666666667],
"America/Whitehorse"=>	[ 60.7166666666667, -135.05],
"America/Dawson"=>	[ 64.0666666666667, -139.416666666667],
"Indian/Cocos"=>	[ -12.1666666666667, 96.9166666666667],
"Africa/Kinshasa"=>	[ -4.3, 15.3],
"Africa/Lubumbashi"=>	[ -11.6666666666667, 27.4666666666667],
"Africa/Bangui"=>	[ 4.36666666666667, 18.5833333333333],
"Africa/Brazzaville"=>	[ -4.26666666666667, 15.2833333333333],
"Europe/Zurich"=>	[ 47.3833333333333, 8.53333333333333],
"Africa/Abidjan"=>	[ 5.31666666666667, -4.03333333333333],
"Pacific/Rarotonga"=>	[ -21.2333333333333, -159.766666666667],
"America/Santiago"=>	[ -33.45, -70.6666666666667],
"Pacific/Easter"=>	[ -27.1666666666667, -109.45],
"Africa/Douala"=>	[ 4.05, 9.7],
"Asia/Shanghai"=>	[ 31.2333333333333, 121.466666666667],
"Asia/Harbin"=>	[ 45.75, 126.683333333333],
"Asia/Chongqing"=>	[ 29.5666666666667, 106.583333333333],
"Asia/Urumqi"=>	[ 43.8, 87.5833333333333],
"Asia/Kashgar"=>	[ 39.4833333333333, 75.9833333333333],
"America/Bogota"=>	[ 4.6, -74.0833333333333],
"America/Costa_Rica"=>	[ 9.93333333333333, -84.0833333333333],
"Europe/Belgrade"=>	[ 44.8333333333333, 20.5],
"America/Havana"=>	[ 23.1333333333333, -82.3666666666667],
"Atlantic/Cape_Verde"=>	[ 14.9166666666667, -23.5166666666667],
"Indian/Christmas"=>	[ -10.4166666666667, 105.716666666667],
"Asia/Nicosia"=>	[ 35.1666666666667, 33.3666666666667],
"Europe/Prague"=>	[ 50.0833333333333, 14.4333333333333],
"Europe/Berlin"=>	[ 52.5, 13.3666666666667],
"Africa/Djibouti"=>	[ 11.6, 43.15],
"Europe/Copenhagen"=>	[ 55.6666666666667, 12.5833333333333],
"America/Dominica"=>	[ 15.3, -61.4],
"America/Santo_Domingo"=>	[ 18.4666666666667, -69.9],
"Africa/Algiers"=>	[ 36.7833333333333, 3.05],
"America/Guayaquil"=>	[ -2.16666666666667, -79.8333333333333],
"Pacific/Galapagos"=>	[ -0.9, -89.6],
"Europe/Tallinn"=>	[ 59.4166666666667, 24.75],
"Africa/Cairo"=>	[ 30.05, 31.25],
"Africa/El_Aaiun"=>	[ 27.15, -13.2],
"Africa/Asmera"=>	[ 15.3333333333333, 38.8833333333333],
"Europe/Madrid"=>	[ 40.4, -3.68333333333333],
"Africa/Ceuta"=>	[ 35.8833333333333, -5.31666666666667],
"Atlantic/Canary"=>	[ 28.1, -15.4],
"Africa/Addis_Ababa"=>	[ 9.03333333333333, 38.7],
"Europe/Helsinki"=>	[ 60.1666666666667, 24.9666666666667],
"Pacific/Fiji"=>	[ -18.1333333333333, 178.416666666667],
"Atlantic/Stanley"=>	[ -51.7, -57.85],
"Pacific/Truk"=>	[ 7.41666666666667, 151.783333333333],
"Pacific/Ponape"=>	[ 6.96666666666667, 158.216666666667],
"Pacific/Kosrae"=>	[ 5.31666666666667, 162.983333333333],
"Atlantic/Faeroe"=>	[ 62.0166666666667, -6.76666666666667],
"Europe/Paris"=>	[ 48.8666666666667, 2.33333333333333],
"Africa/Libreville"=>	[ 0.383333333333333, 9.45],
"Europe/London"=>	[ 51.4666666666667, -0.3],
"America/Grenada"=>	[ 12.05, -61.75],
"Asia/Tbilisi"=>	[ 41.7166666666667, 44.8166666666667],
"America/Cayenne"=>	[ 4.93333333333333, -52.3333333333333],
"Africa/Accra"=>	[ 5.55, -0.216666666666667],
"Europe/Gibraltar"=>	[ 36.1333333333333, -5.35],
"America/Godthab"=>	[ 64.1833333333333, -51.7333333333333],
"America/Danmarkshavn"=>	[ 76.7666666666667, -18.6666666666667],
"America/Scoresbysund"=>	[ 70.5, -22.25],
"America/Thule"=>	[ 76.5666666666667, -68.7833333333333],
"Africa/Banjul"=>	[ 13.4666666666667, -16.65],
"Africa/Conakry"=>	[ 9.51666666666667, -13.7166666666667],
"America/Guadeloupe"=>	[ 16.2333333333333, -61.5333333333333],
"Africa/Malabo"=>	[ 3.75, 8.78333333333333],
"Europe/Athens"=>	[ 37.9666666666667, 23.7166666666667],
"Atlantic/South_Georgia"=>	[ -54.2666666666667, -36.5333333333333],
"America/Guatemala"=>	[ 14.6333333333333, -90.5166666666667],
"Pacific/Guam"=>	[ 13.4666666666667, 144.75],
"Africa/Bissau"=>	[ 11.85, -15.5833333333333],
"America/Guyana"=>	[ 6.8, -58.1666666666667],
"Asia/Hong_Kong"=>	[ 22.2833333333333, 114.15],
"America/Tegucigalpa"=>	[ 14.1, -87.2166666666667],
"Europe/Zagreb"=>	[ 45.8, 15.9666666666667],
"America/Port-au-Prince"=>	[ 18.5333333333333, -72.3333333333333],
"Europe/Budapest"=>	[ 47.5, 19.0833333333333],
"Asia/Jakarta"=>	[ -6.16666666666667, 106.8],
"Asia/Pontianak"=>	[ -0.0333333333333333, 109.333333333333],
"Asia/Makassar"=>	[ -5.11666666666667, 119.4],
"Asia/Jayapura"=>	[ -2.53333333333333, 140.7],
"Europe/Dublin"=>	[ 53.3333333333333, -6.25],
"Asia/Jerusalem"=>	[ 31.7666666666667, 35.2333333333333],
"Asia/Calcutta"=>	[ 22.5333333333333, 88.3666666666667],
"Indian/Chagos"=>	[ -7.33333333333333, 72.4166666666667],
"Asia/Baghdad"=>	[ 33.35, 44.4166666666667],
"Asia/Tehran"=>	[ 35.6666666666667, 51.4333333333333],
"Atlantic/Reykjavik"=>	[ 64.15, -21.85],
"Europe/Rome"=>	[ 41.9, 12.4833333333333],
"America/Jamaica"=>	[ 18, -76.8],
"Asia/Amman"=>	[ 31.95, 35.9333333333333],
"Asia/Tokyo"=>	[ 35.65, 139.733333333333],
"Africa/Nairobi"=>	[ -1.28333333333333, 36.8166666666667],
"Asia/Bishkek"=>	[ 42.9, 74.6],
"Asia/Phnom_Penh"=>	[ 11.55, 104.916666666667],
"Pacific/Tarawa"=>	[ 1.41666666666667, 173],
"Pacific/Enderbury"=>	[ -3.13333333333333, -171.083333333333],
"Pacific/Kiritimati"=>	[ 1.86666666666667, -157.333333333333],
"Indian/Comoro"=>	[ -11.6833333333333, 43.2666666666667],
"America/St_Kitts"=>	[ 17.3, -62.7166666666667],
"Asia/Pyongyang"=>	[ 39.0166666666667, 125.75],
"Asia/Seoul"=>	[ 37.55, 126.966666666667],
"Asia/Kuwait"=>	[ 29.3333333333333, 47.9833333333333],
"America/Cayman"=>	[ 19.3, -81.3833333333333],
"Asia/Almaty"=>	[ 43.25, 76.95],
"Asia/Qyzylorda"=>	[ 44.8, 65.4666666666667],
"Asia/Aqtobe"=>	[ 50.2833333333333, 57.1666666666667],
"Asia/Aqtau"=>	[ 44.5166666666667, 50.2666666666667],
"Asia/Oral"=>	[ 51.2166666666667, 51.35],
"Asia/Vientiane"=>	[ 17.9666666666667, 102.6],
"Asia/Beirut"=>	[ 33.8833333333333, 35.5],
"America/St_Lucia"=>	[ 14.0166666666667, -61],
"Europe/Vaduz"=>	[ 47.15, 9.51666666666667],
"Asia/Colombo"=>	[ 6.93333333333333, 79.85],
"Africa/Monrovia"=>	[ 6.3, -10.7833333333333],
"Africa/Maseru"=>	[ -29.4666666666667, 27.5],
"Europe/Vilnius"=>	[ 54.6833333333333, 25.3166666666667],
"Europe/Luxembourg"=>	[ 49.6, 6.15],
"Europe/Riga"=>	[ 56.95, 24.1],
"Africa/Tripoli"=>	[ 32.9, 13.1833333333333],
"Africa/Casablanca"=>	[ 33.65, -7.58333333333333],
"Europe/Monaco"=>	[ 43.7, 7.38333333333333],
"Europe/Chisinau"=>	[ 47, 28.8333333333333],
"Indian/Antananarivo"=>	[ -18.9166666666667, 47.5166666666667],
"Pacific/Majuro"=>	[ 7.15, 171.2],
"Pacific/Kwajalein"=>	[ 9.08333333333333, 167.333333333333],
"Europe/Skopje"=>	[ 41.9833333333333, 21.4333333333333],
"Africa/Bamako"=>	[ 12.65, -8],
"Asia/Rangoon"=>	[ 16.7833333333333, 96.1666666666667],
"Asia/Ulaanbaatar"=>	[ 47.9166666666667, 106.883333333333],
"Asia/Hovd"=>	[ 48.0166666666667, 91.65],
"Asia/Choibalsan"=>	[ 48.0666666666667, 114.5],
"Asia/Macau"=>	[ 22.2333333333333, 113.583333333333],
"Pacific/Saipan"=>	[ 15.2, 145.75],
"America/Martinique"=>	[ 14.6, -61.0833333333333],
"Africa/Nouakchott"=>	[ 18.1, -15.95],
"America/Montserrat"=>	[ 16.7333333333333, -62.2166666666667],
"Europe/Malta"=>	[ 35.9, 14.5166666666667],
"Indian/Mauritius"=>	[ -20.1666666666667, 57.5],
"Indian/Maldives"=>	[ 4.16666666666667, 73.5],
"Africa/Blantyre"=>	[ -15.7833333333333, 35],
"America/Mexico_City"=>	[ 19.4, -99.15],
"America/Cancun"=>	[ 21.0833333333333, -86.7666666666667],
"America/Merida"=>	[ 20.9666666666667, -89.6166666666667],
"America/Monterrey"=>	[ 25.6666666666667, -100.316666666667],
"America/Mazatlan"=>	[ 23.2166666666667, -106.416666666667],
"America/Chihuahua"=>	[ 28.6333333333333, -106.083333333333],
"America/Hermosillo"=>	[ 29.0666666666667, -110.966666666667],
"America/Tijuana"=>	[ 32.5333333333333, -117.016666666667],
"Asia/Kuala_Lumpur"=>	[ 3.16666666666667, 101.7],
"Asia/Kuching"=>	[ 1.55, 110.333333333333],
"Africa/Maputo"=>	[ -25.9666666666667, 32.5833333333333],
"Africa/Windhoek"=>	[ -22.5666666666667, 17.1],
"Pacific/Noumea"=>	[ -22.2666666666667, 165.5],
"Africa/Niamey"=>	[ 13.5166666666667, 2.11666666666667],
"Pacific/Norfolk"=>	[ -29.05, 167.966666666667],
"Africa/Lagos"=>	[ 6.45, 3.4],
"America/Managua"=>	[ 12.15, -86.2833333333333],
"Europe/Amsterdam"=>	[ 52.3666666666667, 4.9],
"Europe/Oslo"=>	[ 59.9166666666667, 10.75],
"Asia/Katmandu"=>	[ 27.7166666666667, 85.3166666666667],
"Pacific/Nauru"=>	[ -0.516666666666667, 166.916666666667],
"Pacific/Niue"=>	[ -19.0166666666667, 169.916666666667],
"Pacific/Auckland"=>	[ -36.8666666666667, 174.766666666667],
"Pacific/Chatham"=>	[ -43.95, -176.55],
"Asia/Muscat"=>	[ 23.6, 58.5833333333333],
"America/Panama"=>	[ 8.96666666666667, -79.5333333333333],
"America/Lima"=>	[ -12.05, -77.05],
"Pacific/Tahiti"=>	[ -17.5333333333333, -149.566666666667],
"Pacific/Marquesas"=>	[ -9, -139.5],
"Pacific/Gambier"=>	[ -23.1333333333333, -134.95],
"Pacific/Port_Moresby"=>	[ -9.5, 147.166666666667],
"Asia/Manila"=>	[ 14.5833333333333, 121],
"Asia/Karachi"=>	[ 24.8666666666667, 67.05],
"Europe/Warsaw"=>	[ 52.25, 21],
"America/Miquelon"=>	[ 47.05, -56.3333333333333],
"Pacific/Pitcairn"=>	[ -25.0666666666667, -130.083333333333],
"America/Puerto_Rico"=>	[ 18.4666666666667, -66.1],
"Asia/Gaza"=>	[ 31.5, 34.4666666666667],
"Europe/Lisbon"=>	[ 38.7166666666667, -9.13333333333333],
"Atlantic/Madeira"=>	[ 32.6333333333333, -16.9],
"Atlantic/Azores"=>	[ 37.7333333333333, -25.6666666666667],
"Pacific/Palau"=>	[ 7.33333333333333, 134.483333333333],
"America/Asuncion"=>	[ -25.2666666666667, -57.6666666666667],
"Asia/Qatar"=>	[ 25.2833333333333, 51.5333333333333],
"Indian/Reunion"=>	[ -20.8666666666667, 55.4666666666667],
"Europe/Bucharest"=>	[ 44.4333333333333, 26.1],
"Europe/Kaliningrad"=>	[ 54.7166666666667, 20.5],
"Europe/Moscow"=>	[ 55.75, 37.5833333333333],
"Europe/Samara"=>	[ 53.2, 50.15],
"Asia/Yekaterinburg"=>	[ 56.85, 60.6],
"Asia/Omsk"=>	[ 55, 73.4],
"Asia/Novosibirsk"=>	[ 55.0333333333333, 82.9166666666667],
"Asia/Krasnoyarsk"=>	[ 56.0166666666667, 92.8333333333333],
"Asia/Irkutsk"=>	[ 52.2666666666667, 104.333333333333],
"Asia/Yakutsk"=>	[ 62, 129.666666666667],
"Asia/Vladivostok"=>	[ 43.1666666666667, 131.933333333333],
"Asia/Sakhalin"=>	[ 46.9666666666667, 142.7],
"Asia/Magadan"=>	[ 59.5666666666667, 150.8],
"Asia/Kamchatka"=>	[ 53.0166666666667, 158.65],
"Asia/Anadyr"=>	[ 64.75, 177.483333333333],
"Africa/Kigali"=>	[ -1.95, 30.0666666666667],
"Asia/Riyadh"=>	[ 24.6333333333333, 46.7166666666667],
"Pacific/Guadalcanal"=>	[ -9.53333333333333, 160.2],
"Indian/Mahe"=>	[ -4.66666666666667, 55.4666666666667],
"Africa/Khartoum"=>	[ 15.6, 32.5333333333333],
"Europe/Stockholm"=>	[ 59.3333333333333, 18.05],
"Asia/Singapore"=>	[ 1.28333333333333, 103.85],
"Atlantic/St_Helena"=>	[ -15.9166666666667, -5.7],
"Europe/Ljubljana"=>	[ 46.05, 14.5166666666667],
"Arctic/Longyearbyen"=>	[ 78, 16],
"Atlantic/Jan_Mayen"=>	[ 70.9833333333333, -8.08333333333333],
"Europe/Bratislava"=>	[ 48.15, 17.1166666666667],
"Africa/Freetown"=>	[ 8.5, -13.25],
"Europe/San_Marino"=>	[ 43.9166666666667, 12.4666666666667],
"Africa/Dakar"=>	[ 14.6666666666667, -17.4333333333333],
"Africa/Mogadishu"=>	[ 2.06666666666667, 45.3666666666667],
"America/Paramaribo"=>	[ 5.83333333333333, -55.1666666666667],
"Africa/Sao_Tome"=>	[ 0.333333333333333, 6.73333333333333],
"America/El_Salvador"=>	[ 13.7, -89.2],
"Asia/Damascus"=>	[ 33.5, 36.3],
"Africa/Mbabane"=>	[ -26.3, 31.1],
"America/Grand_Turk"=>	[ 21.4666666666667, -71.1333333333333],
"Africa/Ndjamena"=>	[ 12.1166666666667, 15.05],
"Indian/Kerguelen"=>	[ -49.35, 70.2166666666667],
"Africa/Lome"=>	[ 6.13333333333333, 1.21666666666667],
"Asia/Bangkok"=>	[ 13.75, 100.516666666667],
"Asia/Dushanbe"=>	[ 38.5833333333333, 68.8],
"Pacific/Fakaofo"=>	[ -9.36666666666667, -171.233333333333],
"Asia/Dili"=>	[ -8.55, 125.583333333333],
"Asia/Ashgabat"=>	[ 37.95, 58.3833333333333],
"Africa/Tunis"=>	[ 36.8, 10.1833333333333],
"Pacific/Tongatapu"=>	[ -21.1666666666667, 175.166666666667],
"Europe/Istanbul"=>	[ 41.0166666666667, 28.9666666666667],
"America/Port_of_Spain"=>	[ 10.65, -61.5166666666667],
"Pacific/Funafuti"=>	[ -8.51666666666667, 179.216666666667],
"Asia/Taipei"=>	[ 25.05, 121.5],
"Africa/Dar_es_Salaam"=>	[ -6.8, 39.2833333333333],
"Europe/Kiev"=>	[ 50.4333333333333, 30.5166666666667],
"Europe/Uzhgorod"=>	[ 48.6166666666667, 22.3],
"Europe/Zaporozhye"=>	[ 47.8333333333333, 35.1666666666667],
"Europe/Simferopol"=>	[ 44.95, 34.1],
"Africa/Kampala"=>	[ 0.316666666666667, 32.4166666666667],
"Pacific/Johnston"=>	[ 17, -168.5],
"Pacific/Midway"=>	[ 28.2166666666667, -177.366666666667],
"Pacific/Wake"=>	[ 19.2833333333333, 166.616666666667],
"America/New_York"=>	[ 40.7, -74],
"America/Detroit"=>	[ 42.3166666666667, -83.0333333333333],
"America/Kentucky/Louisville"=>	[ 38.25, -85.75],
"America/Kentucky/Monticello"=>	[ 36.8166666666667, -84.8333333333333],
"America/Indiana/Indianapolis"=>	[ 39.7666666666667, -86.15],
"America/Indiana/Marengo"=>	[ 38.3666666666667, -86.3333333333333],
"America/Indiana/Knox"=>	[ 41.2833333333333, -86.6166666666667],
"America/Indiana/Vevay"=>	[ 38.7333333333333, -85.0666666666667],
"America/Chicago"=>	[ 41.85, -87.65],
"America/Menominee"=>	[ 45.1, -87.6],
"America/North_Dakota/Center"=>	[ 47.1, -101.283333333333],
"America/Denver"=>	[ 39.7333333333333, -104.983333333333],
"America/Boise"=>	[ 43.6, -116.2],
"America/Shiprock"=>	[ 36.7833333333333, -108.683333333333],
"America/Phoenix"=>	[ 33.4333333333333, -112.066666666667],
"America/Los_Angeles"=>	[ 34.05, -118.233333333333],
"America/Anchorage"=>	[ 61.2166666666667, -149.9],
"America/Juneau"=>	[ 58.3, -134.416666666667],
"America/Yakutat"=>	[ 59.5333333333333, -139.716666666667],
"America/Nome"=>	[ 64.5, -165.4],
"America/Adak"=>	[ 51.8666666666667, -176.65],
"Pacific/Honolulu"=>	[ 21.3, -157.85],
"America/Montevideo"=>	[ -34.8833333333333, -56.1833333333333],
"Asia/Samarkand"=>	[ 39.6666666666667, 66.8],
"Asia/Tashkent"=>	[ 41.3333333333333, 69.3],
"Europe/Vatican"=>	[ 41.9, 12.45],
"America/St_Vincent"=>	[ 13.15, -61.2333333333333],
"America/Caracas"=>	[ 10.5, -66.9333333333333],
"America/Tortola"=>	[ 18.45, -64.6166666666667],
"America/St_Thomas"=>	[ 18.35, -64.9333333333333],
"Asia/Saigon"=>	[ 10.75, 106.666666666667],
"Pacific/Efate"=>	[ -17.6666666666667, 168.416666666667],
"Pacific/Wallis"=>	[ -13.3, -176.166666666667],
"Pacific/Apia"=>	[ -13.8333333333333, -171.733333333333],
"Asia/Aden"=>	[ 12.75, 45.2],
"Indian/Mayotte"=>	[ -12.7833333333333, 45.2333333333333],
"Africa/Johannesburg"=>	[ -26.25, 28],
"Africa/Lusaka"=>	[ -15.4166666666667, 28.2833333333333],
"Africa/Harare"=>	[ -17.8333333333333, 31.05],
);
1;
